"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * A seeded pseudorandom number generator implementation for
 * generating consistent numeric sequences.
 */
class Random {
    get seed() { return this._seed; }
    set seed(value) {
        this._seed = value;
        this.unique = 0;
    }
    /**
     * Constructs a new `Random` instance using the specified seed.
     * If no seed is specified, the current time (in milliseconds
     * since the epoch) is used.
     *
     * @param   seed
     *          The seed value to apply to this `Random`.
     */
    constructor(seed) {
        this.seed = seed || Date.now();
    }
    /**
     * Returns the next pseudorandom number in this `SeededRandom`'s
     * number sequence, which is a value between 0 (inclusive) and 1
     * (inclusive).
     *
     * @param   bound?
     *          The upper bound of the random number. If specified,
     *          the random number will be a pseudorandom number
     *          between 0 (inclusive) and `bound` (inclusive).
     * @return  This `Random`'s next value.
     */
    next(bound) {
        bound = bound || 1;
        const prn = Math.abs(Math.sin(this.seed + this.unique++));
        return prn * bound;
    }
}
exports.Random = Random;
